setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')

## prepare the data
df <- read.csv("ratings_raw-responses.csv")[,-1]

table (df$lang)
table (df$country)
table (df$country, df$lang)  # rus only from rus, swe only from skandi, en from 4 groups
df$lanc = ifelse (df$lang=="ru", "ru", "other")
df$lanc = ifelse (df$lang=="sv","sv", df$lanc)
df$lanc = ifelse (df$lang=="en" & df$country=="brazil","brazil",df$lanc)
df$lanc = ifelse (df$lang=="en" & df$country=="UKUS","UKUS",df$lanc)
df$lanc = as.factor (df$lanc)
table (df$lanc)  # lanc = linguistic-cultural group

library (lme4)
mod.glmm = glmer (correct~real.em*lanc + (1|file) + (1|sound), data=df, family="binomial", verbose=1, nAGQ=0)  # nAGQ=0 uses a simpler algorithm (otherwise it just runs forever and doesn't converge)
# mod.glmm = glmer (correct~lanc + (1|file) + (1|sound), data=df, family="binomial", verbose=1, nAGQ=0) # for overall effect of lanc
summary(mod.glmm)
drop1(mod.glmm, test="Chisq")

## MCMCglmm model
library (MCMCglmm)
mod.mcmc <- MCMCglmm (correct~real.em*lanc, random = ~file+sound, data=df, nitt=150000, burnin=50000, thin=50, family="categorical")
# summary (mod.mcmc)
# plot (mod.mcmc$Sol)
# saveRDS (mod.mcmc, 'language_mod-mcmc.RDS')

p = cbind (df, predict(mod.mcmc, marginal = ~file+sound, type = "response", interval = "confidence"))
# Prepare for ggplot plotting
dfPlot = as.data.frame(aggregate (fit~real.em+lanc, FUN=mean, data=p))
dfPlot$lwr = aggregate (lwr~real.em+lanc, FUN=mean, data=p)[,3]
dfPlot$upr = aggregate (upr~real.em+lanc, FUN=mean, data=p)[,3]

# to use sample means as point estimates instead of posterior means:
# dfPlot$fit = aggregate (correct~real.em+lanc,df,mean)[,3]

# overall
mod.mcmc.overall <- MCMCglmm (correct~lanc, random = ~file+sound, data=df, nitt=200000, burnin=100000, thin=50, family="categorical")
# plot (mod.mcmc.overall$Sol)
# saveRDS (mod.mcmc.overall, 'language_mod-mcmc-overall.RDS')

p.overall = cbind (df, predict(mod.mcmc.overall, marginal = ~file+sound, type = "response", interval = "confidence"))
dfPlot1 = as.data.frame ( aggregate (fit~lanc, FUN=mean, data=p.overall) )
dfPlot1$lwr = aggregate (lwr~lanc, FUN=mean, data=p.overall)[,2]
dfPlot1$upr = aggregate (upr~lanc, FUN=mean, data=p.overall)[,2]
dfPlot1$real.em = rep("overall",5)

# to use sample means as point estimates instead of posterior means:
# dfPlot1$fit = aggregate (correct~lanc,df,mean)[,2]

dfPlot = rbind (dfPlot, dfPlot1)
colnames (dfPlot)[1] = "emotion"
dfPlot[, 3:5] = dfPlot[, 3:5]*100 # convert to %
dfPlot$emotion = factor (dfPlot$emotion, levels = c("overall", "sadness", "pleasure", "fear", "amusement", "effort", "anger", "disgust", "pain", "joy"))
dfPlot$lanc = factor (dfPlot$lanc, levels=c("UKUS","sv","ru","brazil","other"))

# Plotting
require(ggplot2)
ggplot (data=dfPlot, aes(x=emotion, y=fit, fill=lanc)) +  
  geom_bar(stat="identity", position=position_dodge(.7), width=.7, color="black") +
  geom_errorbar(data=dfPlot, aes(ymin=lwr,ymax=upr), position=position_dodge(.7)) +
  xlab("") +
  ylab("Individual recognition accuracy, %") +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme_bw () +
  scale_fill_manual(values=c("#CCFFFF","skyblue", "#999999", "green", "tomato"),
                    name="Country/language",
                    # breaks=c("en", "ru", "sv"),
                    labels=c("UK / USA","Sweden","Russia","Brazil", "Other")) +
  theme(legend.justification=c(1,1), legend.position=c(1,1)) +
  geom_hline(yintercept=100/9, linetype=2)

ggsave("plots/lanc_MCMCglmm.jpg", width=15, height=7.5, dpi=300, scale = 1.5, units='cm')

# sanity check
aggregate (correct~lanc,df,mean)
aggregate (correct~lanc+real.em,df,mean)
