setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')
require(brms)
require(shinystan)
require(ggplot2)

df <- read.csv("ratings_raw-responses.csv")[,-1]

table (df$country, df$lang)  # rus only from rus, swe only from skandi, en from 4 groups
df$lanc = ifelse (df$lang=="ru", "ru", "other")
df$lanc = ifelse (df$lang=="sv","sv", df$lanc)
df$lanc = ifelse (df$lang=="en" & df$country=="brazil","brazil",df$lanc)
df$lanc = ifelse (df$lang=="en" & df$country=="UKUS","UKUS",df$lanc)
df$lanc = as.factor (df$lanc)
table (df$lanc)  # lanc = linguistic-cultural group


### modeling
## overall
aggregate (correct~lanc, df, mean)
mod0 = brm (correct~lanc + (1|sound) + (1|file), data = df, n.warmup=100, n.iter=2000, n.chains=4, n.cluster=4, family='bernoulli', ranef=F)
# plot (mod0)
# saveRDS(mod0, 'brm_lanc_mod0.RDS')

coda0 = posterior_samples(mod0)
a0 = data.frame (br = coda0[,1], 
                 other = coda0[,1]+coda0[,2],
                 ru = coda0[,1]+coda0[,3],
                 sv = coda0[,1]+coda0[,4],
                 UKUS = coda0[,1]+coda0[,5])
a0 = apply (a0, 2, function(x)1/(1+exp(-x)))
overalls = apply (a0, 2, function(x) quantile(x, probs=c(.025, .5, .975)))


## per linguistic-cultural group
aggregate (correct~lanc+real.em, df, mean)

mod = brm (correct~real.em*lanc + (1|sound) + (1|file), data = df, n.warmup=100, n.iter=2000, n.chains=4, n.cluster=4, family='bernoulli', ranef=F)  
# plot (mod)
# launch_shiny(mod) # for extra diagnostics
# saveRDS(mod, 'brm_lanc_mod.RDS')

a = posterior_samples(mod) 
colnames(a)

dfPlot = data.frame (emotion = rep(c('Amusement','Anger','Disgust','Effort','Fear','Joy','Pain','Pleasure','Sadness'),5), lanc=rep(c('Brazil','Other','Russia','Sweden','UK / USA'),each=9))
dfPlot$fit = rep(0,45); dfPlot$lwr = rep(0,45); dfPlot$upr = rep(0,45)
bigMatrix = matrix(nrow=9*5, ncol=nrow(a))
for (i in 1:9) {
  for (j in 1:5) {
    em = levels(df$real.em)[i]
    l = levels(df$lanc)[j]
    emIdx = paste0("b_real.em",em)
    langIdx = paste0("b_lanc",l)
    interIdx = paste0("b_real.em",em,":lanc",l)
    for (chainIdx in 1:nrow(a)) {
      b_em = ifelse (length(a[chainIdx,emIdx])==0, 0, a[chainIdx,emIdx])
      b_lang = ifelse (length(a[chainIdx,langIdx])==0, 0, a[chainIdx,langIdx])
      b_inter = ifelse (length(a[chainIdx,interIdx])==0, 0, a[chainIdx,interIdx])
      bigMatrix[(i+9*(j-1)),chainIdx] = 1/(1+exp(-  ( a[chainIdx,1] + b_em + b_lang + b_inter) ))
    }  
    dfPlot$fit[(i+9*(j-1))] = apply (as.matrix(bigMatrix[(i+9*(j-1)),]), MARGIN=2, FUN=median)
    dfPlot$lwr[(i+9*(j-1))] = apply (as.matrix(bigMatrix[(i+9*(j-1)),]), MARGIN=2, FUN=function(x) {quantile(x,probs=.025)})
    dfPlot$upr[(i+9*(j-1))] = apply (as.matrix(bigMatrix[(i+9*(j-1)),]), MARGIN=2, FUN=function(x) {quantile(x,probs=.975)})
  }
}

dfPlot [,3:5] = dfPlot[,3:5]*100

# add overall from mod0
dfPlot = rbind (dfPlot, dfPlot[1:5,])
dfPlot$emotion = as.character (dfPlot$emotion)
dfPlot$lanc = as.character (dfPlot$lanc)
dfPlot$emotion[46:50] = rep('Overall',5)
dfPlot$lanc[46:50] = c('Brazil','Other','Russia','Sweden','UK / USA')
dfPlot[46:50, 3] = overalls[2,]*100
dfPlot[46:50, 4] = overalls[1,]*100
dfPlot[46:50, 5] = overalls[3,]*100

dfPlot$emotion = factor (dfPlot$emotion, levels = c("Overall", "Sadness", "Pleasure", "Fear", "Amusement", "Effort", "Anger", "Disgust", "Pain", "Joy"))
dfPlot$lanc = factor (dfPlot$lanc, levels=c("UK / USA","Sweden","Russia","Brazil","Other"))


ggplot (data=dfPlot, aes(x=emotion, y=fit, fill=lanc)) +  
  geom_bar(stat="identity", position=position_dodge(.7), width=.7, color="black") +
  geom_errorbar(data=dfPlot, aes(ymin=lwr,ymax=upr), position=position_dodge(.7), width=.3, size=.3) +
  xlab("") +
  ylab("Individual recognition accuracy, %") +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme_bw () +
  scale_fill_manual(values=c("#CCFFFF","skyblue", "#999999", "green", "tomato"),
                    name="Country/language") +
  theme(legend.justification=c(1,1), legend.position=c(1,1)) +
  geom_hline(yintercept=100/9, linetype=2)

# ggsave ('plots/Fig1_language_stan.jpg', width=15, height=8, units='cm', dpi=300, scale=1.5)