setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')

## prepare the data
df <- read.csv("ratings_raw-responses.csv")[,-1]

library (lme4)
mod.glmm = glmer (correct~real.em*sex + (1|file), data=df, family="binomial")
summary(mod.glmm)
drop1(mod.glmm, test="Chisq")

library (MCMCglmm)
mod.mcmc <- MCMCglmm (correct~real.em*sex, random = ~file+sound, data=df, nitt=150000, burnin=100000, thin=50, family="categorical")
# saveRDS (mod.mcmc, 'sex_mod-mcmc.RDS')
# summary (mod.mcmc) # plot(mod.mcmc)
# plot (mod.mcmc$Sol)

p = cbind (df, predict(mod.mcmc, marginal = ~file+sound, type = "response", interval = "confidence"))
# Prepare for ggplot plotting
dfPlot = as.data.frame(aggregate (fit~real.em+sex, FUN=mean, data=p))
dfPlot$lwr = aggregate (lwr~real.em+sex, FUN=mean, data=p)[,3]
dfPlot$upr = aggregate (upr~real.em+sex, FUN=mean, data=p)[,3]

# to use sample means as point estimates instead of posterior means:
# dfPlot$fit = aggregate (correct~real.em+sex,df,mean)[,3]

# overall
mod.mcmc.overall <- MCMCglmm (correct~sex, random = ~file+sound, data=df, nitt=15000, burnin=1000, thin=1, family="categorical")
# saveRDS (mod.mcmc.overall, 'sex_mod-mcmc-overall.RDS')
# summary (mod.mcmc.overall)
# plot (mod.mcmc.overall$Sol)  

p.overall = cbind (df, predict(mod.mcmc.overall, marginal = ~file+sound, type = "response", interval = "confidence"))
dfPlot1 = as.data.frame ( aggregate (fit~sex, FUN=mean, data=p.overall) )
dfPlot1$lwr = aggregate (lwr~sex, FUN=mean, data=p.overall)[,2]
dfPlot1$upr = aggregate (upr~sex, FUN=mean, data=p.overall)[,2]
dfPlot1$real.em = rep("overall",2)

# to use sample means as point estimates instead of posterior means:
# dfPlot1$fit = aggregate (correct~sex,df,mean)[,2]

dfPlot = rbind (dfPlot, dfPlot1)
colnames (dfPlot)[1] = "emotion"
dfPlot$fit = dfPlot$fit*100
dfPlot$lwr=dfPlot$lwr*100
dfPlot$upr=dfPlot$upr*100
dfPlot$emotion = factor (dfPlot$emotion, levels = c("overall", "sadness", "pleasure", "fear", "amusement", "effort", "anger", "disgust", "pain", "joy"))

# Plotting
library (ggplot2)
ggplot (data=dfPlot, aes(x=emotion, y=fit, fill=sex)) +  
  geom_bar(stat="identity", position=position_dodge(.7)) +
  geom_errorbar(data=dfPlot, aes(ymin=lwr,ymax=upr), position=position_dodge(.7), color="black") +
  xlab("") +
  ylab("Recognition accuracy, %") +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme_bw () +
  scale_fill_manual(values=c("light gray", "dark gray"),
                    name="Gender-age group",
                    breaks=c("AM", "OTHER"),
                    labels=c("Adult men", "Women and children")) +
  theme(legend.justification=c(1,1), legend.position=c(1,1)) +
  geom_hline(yintercept=100/9, linetype=2)

ggsave("plots/sex_MCMCglmm.jpg", width=15, height=7.5, dpi=300, scale = 1.5, units='cm')


# sanity check
aggregate (correct~sex, df, mean)
aggregate (correct~sex+real.em, df, mean)


## duration
library (lme4)
mod.glmm = glmer (correct~duration + (1|file) + (1|sound), data=df, family="binomial")
mod.glmm = glmer (correct~duration*real.em + (1|file) + (1|sound), data=df, family="binomial", nAGQ=0)
summary(mod.glmm)
drop1(mod.glmm, test="Chisq")
