setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')
require(brms)
require(shinystan)
require(ggplot2)

df <- read.csv("ratings_raw-responses.csv")[,-1]

### modeling
## overall
aggregate (correct~sex, df, mean)
mod0 = brm (correct~sex + (1|sound) + (1|file), data = df, n.warmup=100, n.iter=2000, n.chains=4, n.cluster=4, family='bernoulli', ranef=F)  # NB: without random effects, predictions are identical to sample means (as in aggregate...)
# plot (mod0)
# saveRDS(mod0, 'brm_sex_mod0.RDS')
coda0 = posterior_samples(mod0)
a0 = data.frame (male = coda0[,1], female=coda0[,1]+coda0[,2])
a0 = apply (a0, 2, function(x)1/(1+exp(-x)))
df_contrasts0 = quantile (a0[,2]-a0[,1], probs=c(.025,.5,.975))
contrasts0 = c ( paste0( round(df_contrasts0[2]*100,0), ' [', round(df_contrasts0[1]*100,0), ', ', round(df_contrasts0[3]*100,0), ']') )


## per emotion and per gender
aggregate (correct~sex+real.em, df, mean)

mod = brm (correct~real.em*sex + (1|sound) + (1|file), data = df, n.warmup=100, n.iter=2000, n.chains=4, n.cluster=4, family='bernoulli', ranef=F)  
# plot (mod)
# launch_shiny(mod) # for extra diagnostics
# saveRDS(mod, 'brm_sex_mod.RDS')

coda = posterior_samples(mod) 
colnames(coda)

a = data.frame(amusement_male=coda[,1], 
               amusement_female=coda[,1]+coda[,10],
               anger_male=coda[,1]+coda[,2], 
               anger_female=coda[,1]+coda[,2]+coda[,10]+coda[,11],
               disgust_male=coda[,1]+coda[,3], 
               disgust_female=coda[,1]+coda[,3]+coda[,10]+coda[,12],
               effort_male=coda[,1]+coda[,4], 
               effort_female=coda[,1]+coda[,4]+coda[,10]+coda[,13],
               fear_male=coda[,1]+coda[,5], 
               fear_female=coda[,1]+coda[,5]+coda[,10]+coda[,14],
               joy_male=coda[,1]+coda[,6], 
               joy_female=coda[,1]+coda[,6]+coda[,10]+coda[,15],
               pain_male=coda[,1]+coda[,7], 
               pain_female=coda[,1]+coda[,7]+coda[,10]+coda[,16],
               pleasure_male=coda[,1]+coda[,8], 
               pleasure_female=coda[,1]+coda[,8]+coda[,10]+coda[,17],
               sadness_male=coda[,1]+coda[,9], 
               sadness_female=coda[,1]+coda[,9]+coda[,10]+coda[,18])
a = apply (a, 2, function(x)1/(1+exp(-x)))


df_plot = data.frame (emotion = rep(c('Amusement','Anger','Disgust','Effort','Fear','Joy','Pain','Pleasure','Sadness'),each=2), sex=rep(c('Man','Woman/child'),9), lwr=NA, fit=NA, upr=NA)
df_plot
df_plot[,3:5] = t ( apply (a, 2, function(x)quantile(x,probs=c(.025,.5,.975))) )
df_plot[,3:5] = df_plot[,3:5] * 100

# contrasts
df_contrasts = data.frame (emotion = levels(df$real.em), lwr=NA, fit=NA, upr=NA)
for (i in 1:length(levels(df$real.em))) {
  df_contrasts[i,2:4] = quantile (a[,2*i]-a[,2*i-1], probs=c(.025,.5,.975))
}
contrasts = c ( paste0( round(df_contrasts$fit*100,0), ' [', round(df_contrasts$lwr*100,0), ', ', round(df_contrasts$upr*100,0), ']') )

# to add contrasts to the plot, re-label factor levels in the dataframe
df_plot$emotion = as.character(df_plot$emotion)
for (i in 1:length(unique(df_plot$emotion))){
  df_plot$emotion[2*i] = paste0(df_plot$emotion[2*i],'\n',contrasts[i]) # \n for new line - looks good in ggplot
  df_plot$emotion[2*i-1] = paste0(df_plot$emotion[2*i-1],'\n',contrasts[i])
}

# add overall from mod0
df_plot = rbind (df_plot, df_plot[1:2,])
df_plot$emotion[19:20] = rep(paste0('Overall\n',contrasts0),2)
df_plot[19, 3:5] = quantile (a0[,1], probs=c(.025,.5,.975))*100
df_plot[20, 3:5] = quantile (a0[,2], probs=c(.025,.5,.975))*100
ems = sort(unique(df_plot$emotion)) # this is just to plot in a visually nice order
df_plot$emotion = factor (df_plot$emotion, levels = c(ems[7], ems[10], ems[9], ems[5], ems[1], ems[4], ems[2], ems[3], ems[8], ems[6]))

ggplot (df_plot, aes(x=emotion, y=fit, fill=sex)) +
  geom_bar(stat='identity', position=position_dodge(.6), width=.6) + 
  geom_errorbar(aes(ymin=lwr, ymax=upr), position=position_dodge(.6), width=.3, size=.3) +
  geom_hline(yintercept=11.1, linetype=2) +
  scale_y_continuous(breaks=seq(0,100,10)) +
  theme_bw () +
  scale_fill_manual(values=c('gray75','gray40'), name="Caller", labels=c('Adult man','Woman or child')) +
  theme(legend.justification=c(1,1), legend.position=c(1,1)) +
  xlab("") +
  ylab('Recognition accuracy, %') 

# ggsave ('plots/Fig2_sex_stan.jpg', width=15, height=6, units='cm', dpi=300, scale=1.5)
