setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')
library (randomForest)

ut = read.csv ('ratings_260_without-NA.csv')


## model selection
mod1 = randomForest (emotion~pitch_manually + mean_interval + HNR_mean + band_500 + duration + unvoiced + no_max + peak_freq + jitter_local + ampl_sd + meanCallLength, data=ut, importance=TRUE, ntree=2000, strata=ut$emotion, sampsize=rep(min(table(ut$emotion)), length(unique(ut$emotion))))
mod1  # 51% errors with joy, 40% without

mod2 = randomForest (emotion~pitch_manually + HNR_mean + band_500 + duration + unvoiced + peak_freq + jitter_local + ampl_sd + syllableLength_mean + interBurst_mean + interBurst_sd, data=ut, importance=TRUE, ntree=2000, strata=ut$emotion, sampsize=rep(min(table(ut$emotion)), length(unique(ut$emotion))))
mod2   # 51% errors with joy, 40% without
varImpPlot (mod2, type='1')

mod3 = randomForest (emotion~pitch_manually + HNR_mean + band_500 + ampl_sd + interBurst_sd + interBurst_mean, data=ut, importance=TRUE, ntree=2000, strata=ut$emotion, sampsize=rep(min(table(ut$emotion)), length(unique(ut$emotion))))
mod3  # 53% errors with joy, 42% without
varImpPlot (mod3, type='1')



## bootstrap to get standard errors for recognition rates
boot = list (); OOB=matrix()
for (i in 1:100) {
  # ut$emotion = shuffle(ut$emotion) # to get chance level (~11%)
  model.boot = randomForest (emotion ~ pitch_manually + HNR_mean + band_500 + ampl_sd + interBurst_sd + interBurst_mean, data=ut, importance=TRUE, ntree=2000, strata=ut$emotion, sampsize=rep(min(table(ut$emotion)), length(unique(ut$emotion))))  
  boot [[i]] = model.boot$confusion
  OOB[i] = mean (model.boot$err.rate [1000:2000, 1])  # 1 refers to the overall error rate, 2,3,4...10 to particular emotions; 500:1000 are trees from 500 to 1000 (average error, which goes down to a certain limit as the number of trees grown increases)
}
print (1-mean(OOB))  # mean overall bootstrapped accuracy
1-quantile (OOB, c(.025,.975))  # bootstrapped 95% CI for overall accuracy of the model
conf = Reduce("+",boot)/length(boot) # confusion matrix
m = conf[,1:9]  # or 1:9 with joy
m = cbind (m, apply (m, MARGIN=1, FUN="sum"))
n = round (m[,1:9] / m[,10] * 100, 1)
write.csv (n, "~/Downloads/n.csv")

# now for CI's for accuracy per emotion
require(abind)
b <- abind(boot,along = 3)
# apply (b, c(1,2), mean)  # another way to get confusion matrix
m = t (b [,10,])   # just take my word for it... 10 stands for "overall error". Use '9' without joy
sumMat = matrix (nrow=ncol(m),ncol=1); rownames(sumMat) = colnames(m)
for (c in 1:ncol(m)) {
  meamM = (1-round (mean (m[,c]), 3)) * 100
  upr = (1-round (aggregate (m[,c]~1, FUN=function(x) quantile(x, prob=0.025)), 3)) * 100
  lwr = (1-round (aggregate (m[,c]~1, FUN=function(x) quantile(x, prob=0.975)), 3)) * 100
  sumMat[c,1] = paste0 (meamM," [", lwr, ", ", upr, "]") 
}
sumMat
write.csv (sumMat, "~/Downloads/temp.csv")

# Without joy
ut = droplevels (subset (ut, ut$emotion!="joy")) # and repeat from line 16

## hit rate and correct rejection rate, unbiased hit rate, etc
# x = read.csv ("~/Downloads/x.csv") # copy-paste confusion matrix from the article
# rownames(x) = x[,1]; x=x[,-1]
x = conf[, 1 : (ncol(conf)-1)]
out = data.frame (emotion=sort(unique(ut$emotion)),correctDetection=NA,incorrectDetection=NA,correctRejection=NA,incorrectRejection=NA,Hu=NA,chance=NA)
for (i in 1:nrow(x)) {
  out$correctDetection[i] = round (x[i,i] / sum(x[i,]),3) # we say "amusement" given that it is amusement
  out$incorrectDetection[i] = round ( sum(x[-i,i]) / sum(x[-i,]),3) # we say "amusement" given that it is not amusement
  out$correctRejection[i] = round ( sum(x[-i,-i]) / sum(x[-i,]) ,3) # we say "not amusement" given that it is not amusement
  out$incorrectRejection[i] = round ( sum(x[i,-i]) / sum(x[i,]),3) # we say "not amusement" given that it is amusement
  out$Hu[i] = round (x[i,i]^2 / (sum(x[,i])*sum(x[i,])),3)
  out$chance[i] = round ( sum(x[,i])*sum(x[i,])/(sum(x)^2),3 )
}
out[, 2:ncol(out)] = out[, 2:ncol(out)] * 100
summary(out) # to get mean Hu etc
write.csv (out, "~/Downloads/temp.csv")



## predicting human ratings
ut = read.csv ('ratings_260_without-NA.csv')
compiled = read.csv ('ratings_compiled_preprocessed.csv')
ut$pred.em = compiled$emotion

mod4 = randomForest (pred.em~pitch_manually + HNR_mean + band_500 + ampl_sd + interBurst_sd + interBurst_mean, data=ut, importance=TRUE, ntree=2000, strata=ut$pred.em, sampsize=rep(min(table(ut$pred.em)), length(unique(ut$pred.em))))
mod4  # 
varImpPlot (mod4, type='1')
1-mod4$confusion [,10]
