require (mosaic); require (randomForest)
setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')

## For acoustic models
ut = read.csv ('ratings_260_without-NA.csv')

# save probabilities of group membership from RF, use entropy to select "don't know" cases
mod.ut = randomForest (emotion~pitch_manually + HNR_mean + band_500 + ampl_sd + interBurst_sd + interBurst_mean, data=ut, importance=TRUE, ntree=5000, strata=ut$emotion, sampsize=rep(min(table(ut$emotion)), length(unique(ut$emotion))))
ut = cbind (ut, mod.ut$votes)

# calculate entropy
for (i in 1:nrow(ut))  {
  a = ut[i , c( (ncol(ut)-9) : ncol(ut))] + 1e-08  # to avoid zeroes 
  ut$pred.entropy[i] = -sum(log2(a/sum(a))*a/sum(a))  
}

ut$pred.em = mod.ut$predicted # save predicted class from RF model (could also choose the highest vote manually)
ut$correct = ifelse (ut$emotion==ut$pred.em, T, F)
boxplot (pred.entropy~correct, ut) # higher entropy ~ more incorrect classifications

mean(ut$correct)  # accuracy for all decisions
# hist (ut$pred.entropy)  

# let's narrow down by leaving only decisions with entropy < threshold
m = data.frame (entropyThreshold = seq(min(ut$pred.entropy), max(ut$pred.entropy), length.out = 100), accuracy = 0, propCases = 0)
for (i in 1:nrow(m)) {
  m$accuracy[i] = mean( ut [ut$pred.entropy<m$entropyThreshold[i], "correct"] )
  m$propCases[i] = nrow ( ut [ut$pred.entropy<m$entropyThreshold[i],] ) / nrow(ut)
}
plot (accuracy~entropyThreshold,m, type="o", ylim=c(0,1))
points (propCases~entropyThreshold,m,col="lightblue")

# for example, for the better half:
utSm = ut [ut$pred.entropy<median (ut$pred.entropy),]
table (utSm$emotion) # cf: table (ut$emotion)
mean (utSm$correct)
table (utSm$pred.em, utSm$emotion)
aggregate (correct~emotion,utSm,mean)
# what are low-entropy sounds of joy and pain misclassified as?
table (utSm$emotion, utSm$pred.em)

# for each emotion separately
layout (matrix(1:9, ncol=3))
for (em in unique(ut$emotion)) {
  df = ut[ut$emotion==em,]
  m = data.frame (entropyThreshold = seq(min(ut$pred.entropy), max(ut$pred.entropy), length.out = 100), accuracy = 0, propCases = 0)
  for (i in 1:nrow(m)) {
    m$accuracy[i] = mean( df [df$pred.entropy<m$entropyThreshold[i], "correct"] )
    m$propCases[i] = nrow ( df [df$pred.entropy<m$entropyThreshold[i],] ) / nrow(df)
  }
  plot (accuracy~entropyThreshold,m, type="o", ylim=c(0,1), main=em)
  points (propCases~entropyThreshold,m,col="lightblue")
}
layout(matrix(c(1,1)))  # observe that only for joy and pain is low entropy associated with low accuracy!


### For human ratings
compiled = read.csv ("ratings_compiled_preprocessed.csv")[,-1]

# calculate entropy
for (i in 1:nrow(compiled))  {
  a = compiled[i , 2:10] + 1e-08  # to avoid zeroes 
  compiled$pred.entropy[i] = -sum(log2(a/sum(a))*a/sum(a))  
}
# hist (compiled$pred.entropy) 
compiledSm = compiled [compiled$pred.entropy<median(compiled$pred.entropy),]
table (compiledSm$emotion) # cf: table (ut$emotion)
mean (compiledSm$correct)
table (compiledSm$emotion, compiledSm$real.em)
aggregate (correct~real.em,compiledSm,mean)

# for each emotion separately
layout (matrix(1:9, ncol=3))
for (em in unique(compiled$real.em)) {
  df = compiled[compiled$real.em==em,]
  m = data.frame (entropyThreshold = seq(min(compiled$pred.entropy), max(compiled$pred.entropy), length.out = 100), accuracy = 0, propCases = 0)
  for (i in 1:nrow(m)) {
    m$accuracy[i] = mean( df [df$pred.entropy<m$entropyThreshold[i], "correct"] )
    m$propCases[i] = nrow ( df [df$pred.entropy<m$entropyThreshold[i],] ) / nrow(df)
  }
  plot (accuracy~entropyThreshold,m, type="o", ylim=c(0,1), main=em)
  points (propCases~entropyThreshold,m,col="lightblue")
}
layout(matrix(c(1,1)))


