setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')
library (nnet)

df = read.csv ('ratings_260_without-NA.csv')
df$emotionRef <- relevel(df$emotion, ref = "amusement") 

# log-transform pitch for better plotting
df$pitch_manually = log(df$pitch_manually)

## The model
# NB: accommodates any two predictors, optionally with interaction
predictors = c("pitch_manually","HNR_mean")  # check head(df) and pick what you want. E.g. predictors = c("pitch_manually","HNR_mean") 
include.interaction = T

if (include.interaction) {
  predictors = c(predictors, "inter")
  df$inter = df[,predictors[1]] * df [,predictors[2]]
}
data = cbind ( df$emotionRef, subset(df,select=predictors)); colnames(data)[1] = "emotionRef"

formula = paste("emotionRef ~", predictors[1])
for (p in 2:length(predictors)) {
  formula = paste(formula,"+",predictors[p])
}

mod <- multinom(formula, data)   

# set the range of predictors
predRange = matrix(nrow=100,ncol=length(colnames(data)[2:ncol(data)]))
colnames (predRange) = colnames(data)[2:ncol(data)]
for (p in 1:length(predictors)) {
  predRange[,p] = seq(range(data[,predictors[p]])[1], range(data[,predictors[p]])[2], length.out=100)  
}
# for perspective plots, we need a matrix of 100x100 for each emotion. Let's put them all in a single array. dim1 = pitch, dim2 = HNR, dim3 = probability of observing for these values of pitch&HNR
output = array(dim=c(100,100,length(levels(df$emotion))))
for (i in 1:100) {
  for (j in 1:100) {
    d=as.data.frame (t(c(predRange[i,1], predRange[j,2])))
    if (include.interaction) {d$inter = d[,1]*d[,2]}
    output [i,j,] = predict (mod, d, "probs")
  }
}


## plotting - adjust file names and labels as needed
ems = levels(df$emotion)

svg(filename="~/Downloads/temp.svg", width=60, height=40, pointsize=12)

layout (matrix(1:9, ncol=3, byrow=T))
for (i in 1:length(ems)) {  # for each emotion, a separate perspective plot
  z = output [,,i]
  nrz <- nrow(z)   # some stuff to get a color gradient in persp - see help for persp (base)
  ncz <- ncol(z)
  jet.colors <- colorRampPalette( c("lightblue", "yellow") )
  # Generate the desired number of colors from this palette
  nbcol <- 100
  color <- jet.colors(nbcol)
  # Compute the z-value at the facet centres
  zfacet <- z[-1, -1] + z[-1, -ncz] + z[-nrz, -1] + z[-nrz, -ncz]
  # Recode facet z-values into color indices
  facetcol <- cut(zfacet, nbcol)
  persp (predRange[,1], predRange[,2], z, theta = 30, phi = 30, expand = 0.5, col = color[facetcol], zlab="prob", main=ems[i], xlab='Pitch', ylab='Harmonicity', cex.lab = 4, cex.main = 5)   # xlab=predictors[1], ylab=predictors[2]
}
layout (matrix(c(1,1)))

dev.off()  # open temp.svg with gimp, choose ppi 300 and width 18 cm - fits perfectly on a page!
# alternatively, just save file as jpeg size 3500 x ... (186 dpi but can be resized in writer)


## sanity check:
library (ggplot2)
ggplot(data, aes(x=data[,predictors[1]], y=data[,predictors[2]], shape=emotionRef, color=emotionRef)) + 
  geom_point(size=3) +
  scale_shape_manual (name="Emotion", values=c(1,3,5,17,9,7,18,8,22) ) + # for 9 emotions: c(1,3,5,17,9,7,18,8,22)  # for 8, take away 7
  scale_color_manual (name="Emotion", values=c("burlywood2", "black", "blue", "chartreuse", "cornflowerblue", "green", "gray40", "pink", "orangered2") ) +  # for 9 emotions: c("burlywood2", "black", "blue", "chartreuse", "cornflowerblue", "green", "gray40", "pink", "orangered2") # for 8, take away green
  theme_bw() + xlab(predictors[1]) + ylab(predictors[2]) +
  theme(axis.title.x = element_text(size=18),
        axis.title.y = element_text(size=18),
        legend.title = element_text(size = 20, face = "bold"),
        legend.text = element_text(size = 20)) 
