setwd ('/home/allgoodguys/Documents/Studying/Lund_PhD/epistles/01_article_ratings/analysis_final')

df <- read.csv("ratings_raw-responses.csv")[,-1]

df$lanc = ifelse (df$lang=="ru", "ru", "other")
df$lanc = ifelse (df$lang=="sv","sv", df$lanc)
df$lanc = ifelse (df$lang=="en" & df$country=="brazil","brazil",df$lanc)
df$lanc = ifelse (df$lang=="en" & df$country=="UKUS","UKUS",df$lanc)
df$lanc = as.factor (df$lanc)
table (df$lanc)  
spread = aggregate (correct~lanc,df,mean)
aggregate (correct~lanc+real.em,df,mean)


library (lme4)
mod.glmm = glmer (correct~lanc + (1|file) + (1|sound), data=df, family="binomial", verbose=1, nAGQ=0)  
summary(mod.glmm)
drop1(mod.glmm, test="Chisq")


## simulation for power analysis
sdTarget = sd (spread$correct)  # sd of the spread of mean scores in lanc groups
# sdTarget = 0.05 # etc - set the needed value
meanTarget = mean (spread$correct) 

# without random variation per sound
simulate = function (){  
  sim = df
  probs = rnorm (5,meanTarget,sdTarget)
  for (l in 1:length(unique(df$lanc))) {
    len = nrow(subset(sim, sim$lanc==unique(df$lanc)[l]))
    sim$correct[sim$lanc==unique(df$lanc)[l]] = rbinom (len,1,probs[l])
  }
  mod = drop1(glmer (correct~lanc + (1|file) + (1|sound), data=sim, family="binomial", verbose=1, nAGQ=0), test="Chisq")
  return (mod[2,4])
}

# with random variation per sound
spreadSound = aggregate (correct~sound,df,mean)
hist (spreadSound$correct) # essentially unif (0,1)

simulate = function (dataframe=df, verbose=T){  
  sim = dataframe
  probs = rnorm (length(unique(dataframe$lanc)),meanTarget,sdTarget)
  logodds_probs = log (probs / (1-probs))
  probsSound = runif (length(unique(df$sound)),0,1)
  logodds_probsSound = log(probsSound / (1-probsSound))
  for (l in 1:length(unique(df$lanc))) {
    for (s in 1:length(unique(df$sound))) {
      len = nrow(subset(sim, sim$lanc==unique(df$lanc)[l] & sim$sound==unique(df$sound)[s]))
      logodds_probs_ls = logodds_probsSound[s] + (logodds_probs[l]-mean(logodds_probs))
      probs_ls = exp(logodds_probs_ls) / (1+exp(logodds_probs_ls))
      sim$correct[sim$lanc==unique(df$lanc)[l] & sim$sound==unique(df$sound)[s]] = rbinom (len,1, prob=probs_ls)  # I just add the probs of success randomly generated for every sound (unif (0,1)) and for every lanc (nrorm with observed sd ~2% minus mean), on logodds scale 
    }
  }
  if (verbose) {
    print (aggregate (correct~lanc,sim,mean))
    print (paste ('sd =', round (sd(aggregate (correct~lanc,sim,mean)[,'correct']),3)))
  }
  mod = drop1(glmer (correct~lanc + (1|file) + (1|sound), data=sim, family="binomial", verbose=1, nAGQ=0), test="Chisq")
  return (mod[2,4]) # the p-value from the drop1
}

noIterations = 100
simMatrix = data.frame (iteration = 1:noIterations, pValue = rep(NA, noIterations))
for (i in 1:noIterations) {
  simMatrix$pValue[i] = simulate(verbose=F)
}

mean (simMatrix$pValue)
quantile (simMatrix$pValue, probs=c(.025,.975)) # Without random per sound: p=[.000018, .8]  with sdTarget = 2%. With random per sound: [.0002, .77]
nrow(subset (simMatrix, simMatrix$pValue<.05)) / nrow(simMatrix)   # Without random per sound: With sdTarget 2%, we get ~59% of simulations with p<.05 (power 59%). With random per sound: power 42%. With 5 times as much data: power 88%. With 3 times as much data: power 84%. With sdTarget 5%, ~92% power


# how much data is needed for higher stat power?
noIterations = 100
simMatrix = data.frame (iteration = 1:noIterations, pValue = rep(NA, noIterations))
for (i in 1:noIterations) {
  simMatrix$pValue[i] = simulate(rbind(df,df,df))  # pretend we have x 3 times the data
}
